# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/foxtrot',
                'doc_host': 'https://licenseplated.github.io',
                'git_url': 'https://github.com/licenseplated/foxtrot',
                'lib_path': 'foxtrot'},
  'syms': {'foxtrot.core': {'foxtrot.core.say_hello': ('core.html#say_hello', 'foxtrot/core.py')}}}
