# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_core.ipynb.

# %% auto 0
__all__ = ['say_hello']

# %% ../nbs/00_core.ipynb 3
def say_hello(to):
    "Say hello to somebody"
    return f'Hello {to}!'
